Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(167)

Unified Diff: remoting/host/chromoting_host_context.h

Issue 11366226: Rename capture and encode threads to make it clear that they are for video. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/chromoting_host.cc ('k') | remoting/host/chromoting_host_context.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/chromoting_host_context.h
diff --git a/remoting/host/chromoting_host_context.h b/remoting/host/chromoting_host_context.h
index 0250f06df1913c7b60c7bcea50e6e83c46615ed7..ed559630f92c4396c3ebbab61e36ef06ec82aa45 100644
--- a/remoting/host/chromoting_host_context.h
+++ b/remoting/host/chromoting_host_context.h
@@ -44,10 +44,10 @@ class ChromotingHostContext {
// Task runner for the thread used by the ScreenRecorder to capture
// the screen.
- virtual base::SingleThreadTaskRunner* capture_task_runner();
+ virtual base::SingleThreadTaskRunner* video_capture_task_runner();
// Task runner for the thread used to encode video streams.
- virtual base::SingleThreadTaskRunner* encode_task_runner();
+ virtual base::SingleThreadTaskRunner* video_encode_task_runner();
// Task runner for the thread that is used for blocking file
// IO. This thread is used by the URLRequestContext to read proxy
@@ -79,10 +79,10 @@ class ChromotingHostContext {
base::Thread audio_thread_;
// A thread that hosts screen capture.
- base::Thread capture_thread_;
+ base::Thread video_capture_thread_;
- // A thread that hosts all encode operations.
- base::Thread encode_thread_;
+ // A thread that hosts video encode operations.
+ base::Thread video_encode_thread_;
// Thread for blocking IO operations.
base::Thread file_thread_;
@@ -96,8 +96,8 @@ class ChromotingHostContext {
// Task runners wrapping the above threads. These should be declared after
// the corresponding threads to guarantee proper order of destruction.
scoped_refptr<base::SingleThreadTaskRunner> audio_task_runner_;
- scoped_refptr<base::SingleThreadTaskRunner> capture_task_runner_;
- scoped_refptr<base::SingleThreadTaskRunner> encode_task_runner_;
+ scoped_refptr<base::SingleThreadTaskRunner> video_capture_task_runner_;
+ scoped_refptr<base::SingleThreadTaskRunner> video_encode_task_runner_;
scoped_refptr<base::SingleThreadTaskRunner> file_task_runner_;
scoped_refptr<base::SingleThreadTaskRunner> input_task_runner_;
scoped_refptr<base::SingleThreadTaskRunner> network_task_runner_;
« no previous file with comments | « remoting/host/chromoting_host.cc ('k') | remoting/host/chromoting_host_context.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698